@@ -72,7 +72,8 @@ class BaseTrainer(BaseRunner):
         super(BaseTrainer, self).__init__(config)
         self.set_strategy(strategy)
         # Steps and Epochs start from 0
-        self.steps = tf.Variable(0, dtype=tf.int64)  # Step must be int64 to use tf.summary
+        # Step must be int64 to use tf.summary
+        self.steps = tf.Variable(0, trainable=False, dtype=tf.int64)
         self.train_steps_per_epoch = None
         self.eval_steps_per_epoch = None
         # Dataset
@@ -120,12 +121,14 @@ class BaseTrainer(BaseRunner):
         self.config.batch_size = train_bs  # Update batch size fed from arguments
 
         if not train_acs: train_acs = self.config.accumulation_steps
-        self.accumulation_bs = train_bs // train_acs
         self.config.accumulation_steps = train_acs  # update accum steps fed from arguments
 
         self.train_data = train_dataset.create(self.global_batch_size)
         self.train_data_loader = self.strategy.experimental_distribute_dataset(self.train_data)
-        self.train_steps_per_epoch = train_dataset.total_steps
+        if hasattr(self, "accumulation"):
+            self.train_steps_per_epoch = train_dataset.total_steps // self.config.accumulation_steps
+        else:
+            self.train_steps_per_epoch = train_dataset.total_steps
 
     def set_eval_data_loader(self, eval_dataset, eval_bs=None):
         """ Set eval data loader (MUST).
@@ -312,8 +315,8 @@ class BaseTrainer(BaseRunner):
 
     def _check_log_interval(self):
         """Save log interval."""
-        if self.steps % self.config.log_interval_steps == 0 or \
-                self.steps >= self.total_train_steps:
+        if (self.steps % self.config.log_interval_steps == 0) or \
+                (self.total_train_steps and self.steps >= self.total_train_steps):
             self._write_to_tensorboard(self.train_metrics, self.steps, stage="train")
             """Reset train metrics after save it to tensorboard."""
             for metric in self.train_metrics.keys():
@@ -321,14 +324,15 @@ class BaseTrainer(BaseRunner):
 
     def _check_save_interval(self):
         """Save log interval."""
-        if self.steps % self.config.save_interval_steps == 0 or \
-                self.steps >= self.total_train_steps:
+        if (self.steps % self.config.save_interval_steps == 0) or \
+                (self.total_train_steps and self.steps >= self.total_train_steps):
             self.save_checkpoint()
             self.save_model_weights()
 
     def _check_eval_interval(self):
         """Save log interval."""
-        if self.steps % self.config.eval_interval_steps == 0:
+        if (self.steps % self.config.eval_interval_steps == 0) or \
+                (self.total_train_steps and self.steps >= self.total_train_steps):
             self._eval_epoch()
 
     # -------------------------------- UTILS -------------------------------------
